==> calligra_2.3.85.orig.tar.bz2: calligra-2.3.85/plugins/chartshape/ChartShapeFactory.h <==
/* This file is part of the KDE project
   Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KCHART_CHART_SHAPE_FACTORY
#define KCHART_CHART_SHAPE_FACTORY


// Own
#include "ChartShape.h"

// Qt
#include <QStringList>

// Calligra
#include <KoShapeFactoryBase.h>
#include <QVariantList>


class KoShape;
class KoShapeConfigWidgetBase;


class ChartShapePlugin : public QObject
{
    Q_OBJECT
public:

    ChartShapePlugin( QObject * parent,  const QVariantList & );
    ~ChartShapePlugin() {}
};


class ChartShapeFactory : public KoShapeFactoryBase
{
public:
    ChartShapeFactory();
    ~ChartShapeFactory() {}

    bool supports(const KoXmlElement &element, KoShapeLoadingContext &context) const;

    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
    virtual void newDocumentResourceManager(KoDocumentResourceManager *manager) const;

    QList<KoShapeConfigWidgetBase*> createShapeOptionPanels();
};


#endif // KCHART_CHART_SHAPE_FACTORY

==> calligra_2.4.0.orig.tar.bz2: calligra-2.4.0/plugins/chartshape/ChartShapeFactory.h <==
/* This file is part of the KDE project
   Copyright 2007 Stefan Nikolaus <stefan.nikolaus@kdemail.net>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef KCHART_CHART_SHAPE_FACTORY
#define KCHART_CHART_SHAPE_FACTORY


// Own
#include "ChartShape.h"

// Qt
#include <QStringList>

// Calligra
#include <KoShapeFactoryBase.h>
#include <QVariantList>


class KoShape;
class KoShapeConfigWidgetBase;


class ChartShapePlugin : public QObject
{
    Q_OBJECT
public:

    ChartShapePlugin( QObject * parent,  const QVariantList & );
    ~ChartShapePlugin() {}
};


class ChartShapeFactory : public KoShapeFactoryBase
{
public:
    ChartShapeFactory();
    ~ChartShapeFactory() {}

    bool supports(const KoXmlElement &element, KoShapeLoadingContext &context) const;

    virtual KoShape *createDefaultShape(KoDocumentResourceManager *documentResources = 0) const;
    // reimplemented to not create a default shape to just overwrite it afterwards
    virtual KoShape *createShapeFromOdf(const KoXmlElement &element, KoShapeLoadingContext &context);
    virtual void newDocumentResourceManager(KoDocumentResourceManager *manager) const;

    QList<KoShapeConfigWidgetBase*> createShapeOptionPanels();
};


#endif // KCHART_CHART_SHAPE_FACTORY
